mth5.tables package
===================

Submodules
----------

mth5.tables.channel\_table module
---------------------------------

.. automodule:: mth5.tables.channel_table
   :members:
   :undoc-members:
   :show-inheritance:

mth5.tables.mth5\_table module
------------------------------

.. automodule:: mth5.tables.mth5_table
   :members:
   :undoc-members:
   :show-inheritance:

mth5.tables.tf\_table module
----------------------------

.. automodule:: mth5.tables.tf_table
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: mth5.tables
   :members:
   :undoc-members:
   :show-inheritance:
